@@ -22,7 +22,7 @@ def create_testcase(client, testcase_spec):
 
     r = requests.post(url, headers=headers, json=testcase_spec)
     if r.status_code != 200:
-        raise ZAPIError(r.status_code, r.json())
+        raise ZAPIError(r)
 
     return r.json()
 
@@ -36,5 +36,5 @@ def map_testcase_to_requirements(client, map_spec):
 
     r = requests.post(url, headers=headers, json=map_spec)
     if r.status_code != 200:
-        raise ZAPIError(r.status_code, r.json())
+        raise ZAPIError(r)
     return r.json()
