@@ -10,5 +10,5 @@ def get_testcase_tree_by_release_id(client, release_id):
 
     r = requests.get(url, headers=headers)
     if r.status_code != 200:
-        raise ZAPIError(r.status_code, r.json())
+        raise ZAPIError(r)
     return r.json()
