@@ -10,6 +10,6 @@ def get_current_logged_in_users(client):
     }
     r = requests.get(url, headers=headers)
     if r.status_code != 200:
-        raise ZAPIError(r.status_code, r.json())
+        raise ZAPIError(r)
 
     return r.json()
