@@ -1,8 +1,8 @@
 class ZAPIError(Exception):
-    def __init__(self, status_code, error_response):
-        self.message = "ZAPI returned " + str(status_code) + ": " + error_response['errorMsg']
-        self.status_code = status_code
-        self.error_message = error_response['errorMsg']
+    def __init__(self, response_object):
+        self.message = "ZAPI returned " + str(response_object.status_code) + "\nResponse:\n" + response_object.text
+        self.status_code = response_object.status_code
+        self.error_message = response_object.text
         super().__init__(self.message)
 
     pass
